package tech.riemann.ims.entity.material;

import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableName;
import io.swagger.v3.oas.annotations.media.Schema;
import lombok.AllArgsConstructor;
import lombok.Data;
import lombok.EqualsAndHashCode;
import lombok.NoArgsConstructor;
import lombok.experimental.Accessors;
import lombok.experimental.FieldNameConstants;
import lombok.experimental.SuperBuilder;
import org.nutz.dao.entity.annotation.*;
import tech.riemann.ims.entity.IdBaseEntity;
import tech.riemann.ims.enums.ApplyTypeEnum;
import tech.riemann.ims.enums.AuditTypeEnum;
import tech.riemann.ims.enums.ReviewResultEnum;

import java.io.Serial;
import java.time.LocalDateTime;

/**
 * @author mayong
 * @since 2024/11/26 16:53
 */
@Data
@SuperBuilder
@NoArgsConstructor
@AllArgsConstructor
@FieldNameConstants
@EqualsAndHashCode(callSuper = true)
@Accessors(chain = true)
@TableName("t_apply_form")
@Table("t_apply_form")
@Comment("入库/出库/盘点 申请单")
@Schema(name = "ApplyForm", description = "入库/出库/盘点 申请单")
public class ApplyForm extends IdBaseEntity {


    @Serial
    private static final long serialVersionUID = 1L;

    @Schema(description = "类型（1: 采购入库申请 2: 归还入库申请 3: 出库外借申请 4: 盘点申请）", requiredMode = Schema.RequiredMode.NOT_REQUIRED)
    @TableField("af_type")
    @Column("af_type")
    @Comment("类型")
    @ColDefine(type = ColType.INT)
    private ApplyTypeEnum type;

    @Schema(description = "盘点类型（1: 全盘 2: 部分盘点）", requiredMode = Schema.RequiredMode.NOT_REQUIRED)
    @TableField("af_audit_type")
    @Column("af_audit_type")
    @Comment("盘点类型")
    @ColDefine(type = ColType.INT)
    private AuditTypeEnum auditType;

    @Schema(description = "申请人", requiredMode = Schema.RequiredMode.NOT_REQUIRED)
    @TableField("af_applicant")
    @Column("af_applicant")
    @Comment("申请人")
    @ColDefine(notNull = false, width = 128, precision = 0)
    private String applicant;

    @Schema(description = "盘点审核人", requiredMode = Schema.RequiredMode.NOT_REQUIRED)
    @TableField("af_reviewer")
    @Column("af_reviewer")
    @Comment("盘点审核人")
    @ColDefine(notNull = false, width = 128, precision = 0)
    private String reviewer;

    @Schema(description = "盘点人", requiredMode = Schema.RequiredMode.NOT_REQUIRED)
    @TableField("af_taker")
    @Column("af_taker")
    @Comment("盘点人")
    @ColDefine(notNull = false, width = 128, precision = 0)
    private String taker;

    @Schema(description = "申请日期", requiredMode = Schema.RequiredMode.NOT_REQUIRED)
    @TableField("af_apply_date")
    @Column("af_apply_date")
    @Comment("申请日期")
    @ColDefine(type = ColType.DATETIME, notNull = false, width = 128, precision = 0)
    private LocalDateTime applyDate;

    @Schema(description = "是否确认（0: 未确认 1: 已确认）", requiredMode = Schema.RequiredMode.NOT_REQUIRED)
    @TableField("af_is_confirm")
    @Column("af_is_confirm")
    @Comment("是否确认")
    @ColDefine(type = ColType.BOOLEAN, notNull = false, width = 128, precision = 0)
    private Boolean isConfirm;

    @Schema(description = "结果(系统自动生成)", requiredMode = Schema.RequiredMode.NOT_REQUIRED)
    @TableField("af_result")
    @Column("af_result")
    @Comment("结果(系统自动生成)")
    @ColDefine(notNull = false, width = 512, precision = 0)
    private String result;

    @Schema(description = "异常原因", requiredMode = Schema.RequiredMode.NOT_REQUIRED)
    @TableField("af_exception")
    @Column("af_exception")
    @Comment("异常原因")
    @ColDefine(type = ColType.VARCHAR, notNull = false, width = 512, precision = 0)
    private String exception;

    @Schema(description = "处理摘要", requiredMode = Schema.RequiredMode.NOT_REQUIRED)
    @TableField("af_exception_handle")
    @Column("af_exception_handle")
    @Comment("处理摘要")
    @ColDefine(type = ColType.VARCHAR, notNull = false, width = 128, precision = 0)
    private String handle;

    @Schema(description = "审核结果(1-待扫码 2-待提交 3-待审核 4-审核通过 5退回)", requiredMode = Schema.RequiredMode.NOT_REQUIRED)
    @TableField("af_review_result")
    @Column("af_review_result")
    @Comment("审核结果(1-待扫码 2-待提交 3-待审核 4-审核通过 5退回)")
    @ColDefine(notNull = false, width = 128, precision = 0)
    private ReviewResultEnum reviewResult;

}
