package tech.riemann.ims.entity.material;

import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableName;
import io.swagger.v3.oas.annotations.media.Schema;
import lombok.AllArgsConstructor;
import lombok.Data;
import lombok.EqualsAndHashCode;
import lombok.NoArgsConstructor;
import lombok.experimental.Accessors;
import lombok.experimental.FieldNameConstants;
import lombok.experimental.SuperBuilder;
import org.nutz.dao.entity.annotation.*;
import tech.riemann.ims.entity.IdBaseEntity;
import tech.riemann.ims.enums.AssignRuleEnum;

import java.io.Serial;

@Data
@SuperBuilder
@NoArgsConstructor
@AllArgsConstructor
@FieldNameConstants
@EqualsAndHashCode(callSuper = true)
@Accessors(chain = true)
@TableName("t_material")
@Table("t_material")
@Comment("物料")
@Schema(name = "Material", description = "物料")
public class Material extends IdBaseEntity {

    @Serial
    private static final long serialVersionUID = 1L;

    @Schema(description = "编码", requiredMode = Schema.RequiredMode.NOT_REQUIRED)
    @TableField("m_code")
    @Column("m_code")
    @Comment("编码")
    @ColDefine(notNull = false, width = 128, precision = 0)
    private String code;

    @Schema(description = "名称", requiredMode = Schema.RequiredMode.NOT_REQUIRED)
    @TableField("m_name")
    @Column("m_name")
    @Comment("名称")
    @ColDefine(notNull = false, width = 128, precision = 0)
    private String name;

    @Schema(description = "赋码规则(2-低值易耗品（不参与赋码） 1-高价值工具类（参与唯一赋码）", requiredMode = Schema.RequiredMode.NOT_REQUIRED)
    @TableField("m_assign_rule")
    @Column("m_assign_rule")
    @Comment("赋码规则")
    @ColDefine(notNull = false, type = ColType.INT)
    private AssignRuleEnum assignRule; // 0-低值易耗品（不参与赋码） 1-高价值工具类（参与唯一赋码）

    @Schema(description = "类型", requiredMode = Schema.RequiredMode.NOT_REQUIRED)
    @TableField("m_type")
    @Column("m_type")
    @Comment("类型")
    @ColDefine(notNull = false, width = 128, precision = 0)
    private String type;

    @Schema(description = "规格", requiredMode = Schema.RequiredMode.NOT_REQUIRED)
    @TableField("m_spec")
    @Column("m_spec")
    @Comment("规格")
    @ColDefine(notNull = false, width = 128, precision = 0)
    private String spec;


    @Schema(description = "库存数量", requiredMode = Schema.RequiredMode.NOT_REQUIRED)
    @TableField("m_stock")
    @Column("m_stock")
    @Comment("库存数量")
    @ColDefine(notNull = false, type = ColType.INT)
    private Integer stock;

    @Schema(description = "备注", requiredMode = Schema.RequiredMode.NOT_REQUIRED)
    @TableField("m_description")
    @Column("m_description")
    @Comment("备注")
    @ColDefine(notNull = false, width = 500, precision = 0)
    private String description;


}
